@@ -10,10 +10,6 @@
 """Common password and hash generation functions."""
 import datetime
 import hashlib
-try:  # Python > 3.5
-    from hashlib import blake2b
-except ImportError:  # Python 3.5
-    from pyblake2 import blake2b
 import numbers
 import random
 import time
@@ -72,7 +68,7 @@ def get_random_string(length=12, allowed_chars='abcdefghijklmnopqrstuvwxyzABCDEF
         # time a random string is required. This may change the
         # properties of the chosen random sequence slightly, but this
         # is better than absolute predictability.
-        random.seed(hashlib.sha256(('%s%s%s' % (random.getstate(), time.time(), HASHING_KEY)).encode('utf-8')).digest())
+        random.seed(hashlib.sha256(f'{random.getstate()}{time.time()}{HASHING_KEY}'.encode('utf-8')).digest())
     return ''.join(random.choice(allowed_chars) for i in range(length))
 
 
@@ -110,13 +106,13 @@ def make_hash(object_to_hash, **kwargs):
 
     # use the Unlimited fanout hashing protocol outlined in
     #   https://blake2.net/blake2_20130129.pdf
-    final_hash = blake2b(node_depth=1, last_node=True, **BLAKE2B_OPTIONS)
+    final_hash = hashlib.blake2b(node_depth=1, last_node=True, **BLAKE2B_OPTIONS)
 
     for sub in hashes:
         final_hash.update(sub)
 
     # add an empty last leaf node
-    final_hash.update(blake2b(node_depth=0, last_node=True, **BLAKE2B_OPTIONS).digest())
+    final_hash.update(hashlib.blake2b(node_depth=0, last_node=True, **BLAKE2B_OPTIONS).digest())
 
     return final_hash.hexdigest()
 
@@ -127,11 +123,11 @@ def _make_hash(object_to_hash, **_):
     Implementation of the ``make_hash`` function. The hash is created as a
     28 byte integer, and only later converted to a string.
     """
-    raise ValueError('Value of type {} cannot be hashed'.format(type(object_to_hash)))
+    raise ValueError(f'Value of type {type(object_to_hash)} cannot be hashed')
 
 
 def _single_digest(obj_type, obj_bytes=b''):
-    return blake2b(obj_bytes, person=obj_type.encode('ascii'), node_depth=0, **BLAKE2B_OPTIONS).digest()
+    return hashlib.blake2b(obj_bytes, person=obj_type.encode('ascii'), node_depth=0, **BLAKE2B_OPTIONS).digest()
 
 
 _END_DIGEST = _single_digest(')')
@@ -221,7 +217,7 @@ def _(val, **kwargs):
 @_make_hash.register(numbers.Integral)
 def _(val, **kwargs):
     """get the hash of the little-endian signed long long representation of the integer"""
-    return [_single_digest('int', '{}'.format(val).encode('utf-8'))]
+    return [_single_digest('int', f'{val}'.encode('utf-8'))]
 
 
 @_make_hash.register(bool)
@@ -292,5 +288,5 @@ def float_to_text(value, sig):
     :param value: the float value to convert
     :param sig: choose how many digits after the comma should be output
     """
-    fmt = '{{:.{}g}}'.format(sig)
+    fmt = f'{{:.{sig}g}}'
     return fmt.format(value)
