@@ -126,7 +126,7 @@ def process_function(node_class):
 
             # If any kwargs remain, the spec should be dynamic, so we raise if it isn't
             if kwargs and not process_class.spec().inputs.dynamic:
-                raise ValueError('{} does not support these kwargs: {}'.format(function.__name__, kwargs.keys()))
+                raise ValueError(f'{function.__name__} does not support these kwargs: {kwargs.keys()}')
 
             process = process_class(inputs=inputs, runner=runner)
 
@@ -186,6 +186,8 @@ def process_function(node_class):
         decorated_function.run_get_node = run_get_node
         decorated_function.is_process_function = True
         decorated_function.node_class = node_class
+        decorated_function.process_class = process_class
+        decorated_function.recreate_from = process_class.recreate_from
         decorated_function.spec = process_class.spec
 
         return decorated_function
@@ -303,7 +305,7 @@ class FunctionProcess(Process):
         # the input link to be completely lost.
         if cls.spec().inputs.dynamic and nargs > nparameters:
             name = cls._func.__name__
-            raise TypeError('{}() takes {} positional arguments but {} were given'.format(name, nparameters, nargs))
+            raise TypeError(f'{name}() takes {nparameters} positional arguments but {nargs} were given')
 
     @classmethod
     def create_inputs(cls, *args, **kwargs):
