@@ -21,7 +21,6 @@ from aiida.orm.implementation.querybuilder import BackendQueryBuilder
 
 
 class jsonb_array_length(FunctionElement):  # pylint: disable=invalid-name
-    # pylint: disable=too-few-public-methods
     name = 'jsonb_array_len'
 
 
@@ -30,11 +29,10 @@ def compile(element, compiler, **_kw):  # pylint: disable=function-redefined, re
     """
     Get length of array defined in a JSONB column
     """
-    return 'jsonb_array_length(%s)' % compiler.process(element.clauses)
+    return f'jsonb_array_length({compiler.process(element.clauses)})'
 
 
 class array_length(FunctionElement):  # pylint: disable=invalid-name
-    # pylint: disable=too-few-public-methods
     name = 'array_len'
 
 
@@ -43,11 +41,10 @@ def compile(element, compiler, **_kw):  # pylint: disable=function-redefined
     """
     Get length of array defined in a JSONB column
     """
-    return 'array_length(%s)' % compiler.process(element.clauses)
+    return f'array_length({compiler.process(element.clauses)})'
 
 
 class jsonb_typeof(FunctionElement):  # pylint: disable=invalid-name
-    # pylint: disable=too-few-public-methods
     name = 'jsonb_typeof'
 
 
@@ -56,7 +53,7 @@ def compile(element, compiler, **_kw):  # pylint: disable=function-redefined
     """
     Get length of array defined in a JSONB column
     """
-    return 'jsonb_typeof(%s)' % compiler.process(element.clauses)
+    return f'jsonb_typeof({compiler.process(element.clauses)})'
 
 
 class SqlaQueryBuilder(BackendQueryBuilder):
@@ -65,7 +62,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
     schema defined in backends.sqlalchemy.models
     """
 
-    # pylint: disable=redefined-outer-name, too-many-public-methods
+    # pylint: disable=redefined-outer-name,too-many-public-methods
 
     def __init__(self, backend):
         BackendQueryBuilder.__init__(self, backend)
@@ -130,7 +127,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
         # The update of expansions makes sense only when AliasedClass is provided
         if hasattr(alias, '_sa_class_manager'):
             if '_metadata' in expansions:
-                raise NotExistent("_metadata doesn't exist for {}. Please try metadata.".format(alias))
+                raise NotExistent(f"_metadata doesn't exist for {alias}. Please try metadata.")
 
             return self.get_corresponding_properties(alias.__tablename__, expansions, self.outer_to_inner_schema)
 
@@ -226,10 +223,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
                 raise InputValidationError('You have to give an integer when comparing to a length')
         elif operator in ('like', 'ilike'):
             if not isinstance(value, str):
-                raise InputValidationError(
-                    'Value for operator {} has to be a string (you gave {})'
-                    ''.format(operator, value)
-                )
+                raise InputValidationError(f'Value for operator {operator} has to be a string (you gave {value})')
 
         elif operator == 'in':
             try:
@@ -239,7 +233,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
             if not value_type_set:
                 raise InputValidationError('Value for operator `in` is an empty list')
             if len(value_type_set) > 1:
-                raise InputValidationError('Value for operator `in` contains more than one type: {}'.format(value))
+                raise InputValidationError(f'Value for operator `in` contains more than one type: {value}')
         elif operator in ('and', 'or'):
             expressions_for_this_path = []
             for filter_operation_dict in value:
@@ -301,7 +295,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
                 type_filter = jsonb_typeof(path_in_json) == 'null'
                 casted_entity = path_in_json.astext.cast(JSONB)  # BOOLEANS?
             else:
-                raise TypeError('Unknown type {}'.format(type(value)))
+                raise TypeError(f'Unknown type {type(value)}')
             return type_filter, casted_entity
 
         if column is None:
@@ -328,10 +322,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
             #  Possible types are object, array, string, number, boolean, and null.
             valid_types = ('object', 'array', 'string', 'number', 'boolean', 'null')
             if value not in valid_types:
-                raise InputValidationError(
-                    'value {} for of_type is not among valid types\n'
-                    '{}'.format(value, valid_types)
-                )
+                raise InputValidationError(f'value {value} for of_type is not among valid types\n{valid_types}')
             expr = jsonb_typeof(database_entity) == value
         elif operator == 'like':
             type_filter, casted_entity = cast_according_to_type(database_entity, value)
@@ -363,7 +354,7 @@ class SqlaQueryBuilder(BackendQueryBuilder):
             ],
                         else_=False)
         else:
-            raise InputValidationError('Unknown operator {} for filters in JSON field'.format(operator))
+            raise InputValidationError(f'Unknown operator {operator} for filters in JSON field')
         return expr
 
     @staticmethod
@@ -375,4 +366,4 @@ class SqlaQueryBuilder(BackendQueryBuilder):
         """
         Given the backend specific alias, return the column names that correspond to the aliased table.
         """
-        return [str(c).replace(alias.__table__.name + '.', '') for c in alias.__table__.columns]
+        return [str(c).replace(f'{alias.__table__.name}.', '') for c in alias.__table__.columns]
