@@ -53,15 +53,11 @@ def validate_full_type(full_type):
 
     if FULL_TYPE_CONCATENATOR not in full_type:
         raise ValueError(
-            'full type `{}` does not include the required concatenator symbol `{}`.'.format(
-                full_type, FULL_TYPE_CONCATENATOR
-            )
+            f'full type `{full_type}` does not include the required concatenator symbol `{FULL_TYPE_CONCATENATOR}`.'
         )
     elif full_type.count(FULL_TYPE_CONCATENATOR) > 1:
         raise ValueError(
-            'full type `{}` includes the concatenator symbol `{}` more than once.'.format(
-                full_type, FULL_TYPE_CONCATENATOR
-            )
+            f'full type `{full_type}` includes the concatenator symbol `{FULL_TYPE_CONCATENATOR}` more than once.'
         )
 
 
@@ -78,7 +74,7 @@ def construct_full_type(node_type, process_type):
     if process_type is None:
         process_type = ''
 
-    return '{}{}{}'.format(node_type, FULL_TYPE_CONCATENATOR, process_type)
+    return f'{node_type}{FULL_TYPE_CONCATENATOR}{process_type}'
 
 
 def get_full_type_filters(full_type):
@@ -96,10 +92,10 @@ def get_full_type_filters(full_type):
 
     for entry in (node_type, process_type):
         if entry.count(LIKE_OPERATOR_CHARACTER) > 1:
-            raise ValueError('full type component `{}` contained more than one like-operator character'.format(entry))
+            raise ValueError(f'full type component `{entry}` contained more than one like-operator character')
 
         if LIKE_OPERATOR_CHARACTER in entry and entry[-1] != LIKE_OPERATOR_CHARACTER:
-            raise ValueError('like-operator character in full type component `{}` is not at the end'.format(entry))
+            raise ValueError(f'like-operator character in full type component `{entry}` is not at the end')
 
     if LIKE_OPERATOR_CHARACTER in node_type:
         # Remove the trailing `LIKE_OPERATOR_CHARACTER`, escape the string and reattach the character
@@ -107,16 +103,26 @@ def get_full_type_filters(full_type):
         node_type = escape_for_sql_like(node_type) + LIKE_OPERATOR_CHARACTER
         filters['node_type'] = {'like': node_type}
     else:
-        filters['node_type'] = escape_for_sql_like(node_type)
+        filters['node_type'] = {'==': node_type}
 
     if LIKE_OPERATOR_CHARACTER in process_type:
-        # Remove the trailing `LIKE_OPERATOR_CHARACTER`, escape the string and reattach the character
+        # Remove the trailing `LIKE_OPERATOR_CHARACTER` ()
+        # If that was the only specification, just ignore this filter (looking for any process_type)
+        # If there was more: escape the string and reattach the character
         process_type = process_type[:-1]
-        process_type = escape_for_sql_like(process_type) + LIKE_OPERATOR_CHARACTER
-        filters['process_type'] = {'like': process_type}
+        if process_type:
+            process_type = escape_for_sql_like(process_type) + LIKE_OPERATOR_CHARACTER
+            filters['process_type'] = {'like': process_type}
     else:
         if process_type:
-            filters['process_type'] = escape_for_sql_like(process_type)
+            filters['process_type'] = {'==': process_type}
+        else:
+            # A `process_type=''` is used to represents both `process_type='' and `process_type=None`.
+            # This is because there is no simple way to single out null `process_types`, and therefore
+            # we consider them together with empty-string process_types.
+            # Moreover, the existence of both is most likely a bug of migrations and thus both share
+            # this same "erroneous" origin.
+            filters['process_type'] = {'or': [{'==': ''}, {'==': None}]}
 
     return filters
 
@@ -144,7 +150,7 @@ def load_entry_point_from_full_type(full_type):
         try:
             return load_entry_point_from_string(process_type)
         except EntryPointError:
-            raise EntryPointError('could not load entry point `{}`'.format(process_type))
+            raise EntryPointError(f'could not load entry point `{process_type}`')
 
     elif node_type.startswith(data_prefix):
 
@@ -154,7 +160,7 @@ def load_entry_point_from_full_type(full_type):
         try:
             return load_entry_point('aiida.data', entry_point_name)
         except EntryPointError:
-            raise EntryPointError('could not load entry point `{}`'.format(process_type))
+            raise EntryPointError(f'could not load entry point `{process_type}`')
 
     # Here we are dealing with a `ProcessNode` with a `process_type` that is not an entry point string.
     # Which means it is most likely a full module path (the fallback option) and we cannot necessarily load the
@@ -192,18 +198,26 @@ class Namespace(MutableMapping):
         'process.workflow.workchain.': 'process.workflow.workchain.WorkChainNode.|aiida.workflows:{plugin_name}.%',
     }
 
+    process_full_type_mapping_unplugged = {
+        'process.calculation.calcjob.': 'process.calculation.calcjob.CalcJobNode.|{plugin_name}.%',
+        'process.calculation.calcfunction.': 'process.calculation.calcfunction.CalcFunctionNode.|{plugin_name}.%',
+        'process.workflow.workfunction.': 'process.workflow.workfunction.WorkFunctionNode.|{plugin_name}.%',
+        'process.workflow.workchain.': 'process.workflow.workchain.WorkChainNode.|{plugin_name}.%',
+    }
+
     def __str__(self):
         import json
         return json.dumps(self.get_description(), sort_keys=True, indent=4)
 
-    def __init__(self, namespace, path=None, label=None, full_type=None, is_leaf=True):
+    def __init__(self, namespace, path=None, label=None, full_type=None, counter=None, is_leaf=True):
         """Construct a new node class namespace."""
-        # pylint: disable=super-init-not-called
+        # pylint: disable=super-init-not-called, too-many-arguments
         self._namespace = namespace
         self._path = path if path else namespace
         self._full_type = self._infer_full_type(full_type)
         self._subspaces = {}
         self._is_leaf = is_leaf
+        self._counter = counter
 
         try:
             self._label = label if label is not None else self.mapping_path_to_label[path]
@@ -230,10 +244,15 @@ class Namespace(MutableMapping):
             for basepath, full_type_template in self.process_full_type_mapping.items():
                 if full_type.startswith(basepath):
                     plugin_name = strip_prefix(full_type, basepath)
-                    full_type = full_type_template.format(plugin_name=plugin_name)
+                    if plugin_name.startswith(DEFAULT_NAMESPACE_LABEL):
+                        temp_type_template = self.process_full_type_mapping_unplugged[basepath]
+                        plugin_name = strip_prefix(plugin_name, DEFAULT_NAMESPACE_LABEL + '.')
+                        full_type = temp_type_template.format(plugin_name=plugin_name)
+                    else:
+                        full_type = full_type_template.format(plugin_name=plugin_name)
                     return full_type
 
-        full_type += '.{}{}'.format(LIKE_OPERATOR_CHARACTER, FULL_TYPE_CONCATENATOR)
+        full_type += f'.{LIKE_OPERATOR_CHARACTER}{FULL_TYPE_CONCATENATOR}'
 
         if full_type.startswith('process.'):
             full_type += LIKE_OPERATOR_CHARACTER
@@ -271,10 +290,19 @@ class Namespace(MutableMapping):
             'full_type': self._full_type,
             'label': self._label,
             'path': self._path,
-            'subspaces': []
+            'subspaces': [],
         }
+
         for _, port in self._subspaces.items():
-            result['subspaces'].append(port.get_description())
+            subspace_result = port.get_description()
+            result['subspaces'].append(subspace_result)
+            if 'counter' in subspace_result:
+                if self._counter is None:
+                    self._counter = 0
+                self._counter = self._counter + subspace_result['counter']
+
+        if self._counter is not None:
+            result['counter'] = self._counter
 
         return result
 
@@ -290,7 +318,7 @@ class Namespace(MutableMapping):
         :raises: ValueError if any sub namespace is occupied by a non-Namespace port
         """
         if not isinstance(name, str):
-            raise ValueError('name has to be a string type, not {}'.format(type(name)))
+            raise ValueError(f'name has to be a string type, not {type(name)}')
 
         if not name:
             raise ValueError('name cannot be an empty string')
@@ -298,7 +326,7 @@ class Namespace(MutableMapping):
         namespace = name.split(self.namespace_separator)
         port_name = namespace.pop(0)
 
-        path = '{}{}{}'.format(self._path, self.namespace_separator, port_name)
+        path = f'{self._path}{self.namespace_separator}{port_name}'
 
         # If this is True, the (sub) port namespace does not yet exist, so we create it
         if port_name not in self:
@@ -323,7 +351,7 @@ class Namespace(MutableMapping):
             # namespace is the "concrete" version of the namespace, so we add the leaf version to the namespace.
             elif not self[port_name].is_leaf and not namespace:
                 kwargs['is_leaf'] = True
-                self[port_name][port_name] = self.__class__(port_name, path='{}.{}'.format(path, port_name), **kwargs)
+                self[port_name][port_name] = self.__class__(port_name, path=f'{path}.{port_name}', **kwargs)
 
         # If there is still `namespace` left, we create the next namespace
         if namespace:
@@ -333,15 +361,22 @@ class Namespace(MutableMapping):
         return self[port_name]
 
 
-def get_node_namespace():
+def get_node_namespace(user_pk=None, count_nodes=False):
     """Return the full namespace of all available nodes in the current database.
 
     :return: complete node `Namespace`
     """
+    # pylint: disable=too-many-branches
     from aiida import orm
     from aiida.plugins.entry_point import is_valid_entry_point_string, parse_entry_point_string
 
-    builder = orm.QueryBuilder().append(orm.Node, project=['node_type', 'process_type']).distinct()
+    filters = {}
+    if user_pk is not None:
+        filters['user_id'] = user_pk
+
+    builder = orm.QueryBuilder().append(orm.Node, filters=filters, project=['node_type', 'process_type']).distinct()
+
+    # All None instances of process_type are turned into ''
     unique_types = {(node_type, process_type if process_type else '') for node_type, process_type in builder.all()}
 
     # First we create a flat list of all "leaf" node types.
@@ -350,10 +385,11 @@ def get_node_namespace():
     for node_type, process_type in unique_types:
 
         label = None
+        counter = None
         namespace = None
 
         if process_type:
-            # Process nodes
+            # Only process nodes
             parts = node_type.rsplit('.', 2)
             if is_valid_entry_point_string(process_type):
                 _, entry_point_name = parse_entry_point_string(process_type)
@@ -361,10 +397,10 @@ def get_node_namespace():
                 namespace = '.'.join(parts[:-2] + [entry_point_name])
             else:
                 label = process_type.rsplit('.', 1)[-1]
-                namespace = '.'.join(parts[:-2] + [DEFAULT_NAMESPACE_LABEL, label])
+                namespace = '.'.join(parts[:-2] + [DEFAULT_NAMESPACE_LABEL, process_type])
 
         else:
-            # Data nodes
+            # Data nodes and process nodes without process type (='' or =None)
             parts = node_type.rsplit('.', 2)
             try:
                 label = parts[-2]
@@ -372,12 +408,32 @@ def get_node_namespace():
             except IndexError:
                 continue
 
+        if count_nodes:
+            builder = orm.QueryBuilder()
+            concat_filters = [{'node_type': {'==': node_type}}]
+
+            if node_type.startswith('process.'):
+                if process_type:
+                    concat_filters.append({'process_type': {'==': process_type}})
+                else:
+                    concat_filters.append({'process_type': {'or': [{'==': ''}, {'==': None}]}})
+
+            if user_pk:
+                concat_filters.append({'user_id': {'==': user_pk}})
+
+            if len(concat_filters) == 1:
+                builder.append(orm.Node, filters=concat_filters[0])
+            else:
+                builder.append(orm.Node, filters={'and': concat_filters})
+
+            counter = builder.count()
+
         full_type = construct_full_type(node_type, process_type)
-        namespaces.append((namespace, label, full_type))
+        namespaces.append((namespace, label, full_type, counter))
 
     node_namespace = Namespace('node')
 
-    for namespace, label, full_type in sorted(namespaces, key=lambda x: x[0], reverse=False):
-        node_namespace.create_namespace(namespace, label=label, full_type=full_type)
+    for namespace, label, full_type, counter in sorted(namespaces, key=lambda x: x[0], reverse=False):
+        node_namespace.create_namespace(namespace, label=label, full_type=full_type, counter=counter)
 
     return node_namespace
